@@ -34,7 +34,7 @@ void comp_prod(city_info_t *, bool);
 void
 comp_move(int nmoves) 
 {
-    void do_cities(), do_pieces(), check_endgame();
+    void do_cities(void), do_pieces(void), check_endgame(void);
 
     int i;
     piece_info_t *obj;
@@ -366,7 +366,7 @@ static path_map_t path_map[MAP_SIZE];
 void
 do_pieces(void) 
 {
-    void cpiece_move();
+    void cpiece_move(piece_info_t *);
 
     int i;
     piece_info_t *obj, *next_obj;
@@ -389,12 +389,10 @@ objective.
 void
 cpiece_move(piece_info_t *obj)
 {
-    void move1();
+    void move1(piece_info_t *);
 
     bool changed_loc;
     int max_hits;
-    loc_t saved_loc;
-    city_info_t *cityp;
 
     if (obj->type == SATELLITE) {
 	move_sat (obj);
@@ -406,11 +404,12 @@ cpiece_move(piece_info_t *obj)
     max_hits = piece_attr[obj->type].max_hits;
 
     if (obj->type == FIGHTER) { /* init fighter range */
-	cityp = find_city (obj->loc);
+	city_info_t *cityp = find_city (obj->loc);
 	if (cityp != NULL) obj->range = piece_attr[FIGHTER].range;
     }
 	
     while (obj->moved < obj_moves (obj)) {
+	loc_t saved_loc;
 	saved_loc = obj->loc; /* remember starting location */
 	move1 (obj);
 	if (saved_loc != obj->loc) changed_loc = true;
@@ -441,7 +440,8 @@ Move a piece one square.
 void
 move1(piece_info_t *obj)
 {
-    void army_move(), transport_move(), fighter_move(), ship_move();
+    void army_move(piece_info_t *), transport_move(piece_info_t *);
+    void fighter_move(piece_info_t *), ship_move(piece_info_t *);
 
     switch (obj->type) {
     case ARMY: army_move (obj); break;
@@ -483,10 +483,12 @@ destination.  (If there is no destination, sit around and wait.)
 void
 army_move(piece_info_t *obj)
 {
-    loc_t move_away();
-    loc_t find_attack();
-    void make_army_load_map(), make_unload_map(), make_tt_load_map();
-    void board_ship();
+    loc_t move_away(view_map_t *, loc_t, char *);
+    loc_t find_attack(loc_t, char *, char *);
+    void make_army_load_map(piece_info_t *, view_map_t *, view_map_t *);
+    void make_unload_map(view_map_t *, view_map_t *);
+    void make_tt_load_map(view_map_t *, view_map_t *);
+    void board_ship(piece_info_t *, path_map_t *, loc_t);
 	
     loc_t new_loc;
     path_map_t path_map2[MAP_SIZE];
@@ -760,12 +762,11 @@ load_army(piece_info_t *obj)
 {
     piece_info_t *p;
     int i;
-    loc_t x_loc;
 
     p = find_best_tt (obj->ship, obj->loc); /* look here first */
 
     for (i = 0; i < 8; i++) { /* try surrounding squares */
-	x_loc = obj->loc + dir_offset[i];
+	loc_t x_loc = obj->loc + dir_offset[i];
 	if (map[x_loc].on_board)
 	    p = find_best_tt (p, x_loc);
 
@@ -792,11 +793,10 @@ the correct terrain.
 loc_t
 move_away(view_map_t *vmap, loc_t loc, char *terrain)
 {
-    loc_t new_loc;
     int i;
 
     for (i = 0; i < 8; i++) {
-	new_loc = loc + dir_offset[i];
+	loc_t new_loc = loc + dir_offset[i];
 	if (map[new_loc].on_board
 	    && strchr (terrain, vmap[new_loc].contents))
 	    return (new_loc);
@@ -815,14 +815,14 @@ best of these.
 loc_t
 find_attack(loc_t loc, char *obj_list, char *terrain)
 {
-    loc_t new_loc, best_loc;
+    loc_t best_loc;
     int i, best_val;
     char *p;
 
     best_loc = loc; /* nothing found yet */
     best_val = INFINITY;
     for (i = 0; i < 8; i++) {
-	new_loc = loc + dir_offset[i];
+	loc_t new_loc = loc + dir_offset[i];
 
 	if (map[new_loc].on_board /* can we move here? */
 	    && strchr (terrain, map[new_loc].contents)) {
@@ -851,8 +851,6 @@ Transports become 'loading' when empty, and 'unloading' when full.
 void
 transport_move(piece_info_t *obj)
 {
-    void tt_do_move();
-
     loc_t new_loc;
 
     /* empty transports can attack */
