@@ -75,7 +75,7 @@ bool automove; /* true iff user is in automove mode */
 bool resigned; /* true iff computer resigned */
 bool debug; /* true iff in debugging mode */
 bool print_debug; /* true iff we print debugging stuff */
-bool print_vmap; /* true iff we print view maps */
+char print_vmap; /* the map-printing mode */
 bool trace_pmap; /* true if we are tracing pmaps */
 int win; /* set when game is over - not a bool */
 char jnkbuf[STRSIZE]; /* general purpose temporary buffer */
