@@ -174,13 +174,15 @@ void place_cities(void)
 {
     count_t regen_land();
 
-    count_t placed, i;
-    loc_t loc;
+    count_t placed;
     count_t num_land;
 
     num_land = 0; /* nothing in land array yet */
     placed = 0; /* nothing placed yet */
     while (placed < NUM_CITY) {
+	count_t i;
+	loc_t loc;
+
 	while (num_land == 0) num_land = regen_land (placed);
 	i = irand (num_land-1); /* select random piece of land */
 	loc = land[i];
@@ -302,7 +304,7 @@ bool select_cities(void)
 {
     void find_cont(void), make_pair(void);
 
-    loc_t compi, useri;
+    loc_t compi;
     city_info_t *compp, *userp;
     int comp_cont, user_cont;
     int pair;
@@ -324,7 +326,7 @@ bool select_cities(void)
     compp = cont_tab[comp_cont].cityp[compi];
 
     do { /* select different user city */
-	useri = irand ((long)cont_tab[user_cont].ncity);
+	loc_t useri = irand ((long)cont_tab[user_cont].ncity);
 	userp = cont_tab[user_cont].cityp[useri];
     } while (userp == compp);
 
@@ -507,6 +509,10 @@ tell the user why.
 #define wbuf(buf) if (!xwrite (f, (char *)buf, sizeof (buf))) return
 #define wval(val) if (!xwrite (f, (char *)&val, sizeof (val))) return
 
+#define SAVECOOKIE	"EMPSAVE 1\n"	/* increase digit when format changes */
+
+static char buf[32];
+
 void save_game(void)
 {
     FILE *f; /* file to save game in */
@@ -516,6 +522,7 @@ void save_game(void)
 	perror ("Cannot save saved game");
 	return;
     }
+    wbuf(SAVECOOKIE);
     wbuf (map);
     wbuf (comp_map);
     wbuf (user_map);
@@ -547,7 +554,7 @@ We return true if we succeed, otherwise false.
 
 int restore_game(void)
 {
-    void read_embark();
+    void read_embark(piece_info_t *, int);
 	
     FILE *f; /* file to save game in */
     long i;
@@ -559,6 +566,11 @@ int restore_game(void)
 	perror ("Cannot open saved game");
 	return (false);
     }
+    if (fgets(buf, sizeof(buf), f) == NULL)
+	return false;
+    else if (strcmp(buf, SAVECOOKIE) != 0)
+	return false;
+    i = fread(buf, 1, sizeof(char), f);	/* skip trailing nul after cookie */ 
     rbuf (map);
     rbuf (comp_map);
     rbuf (user_map);
@@ -639,10 +651,9 @@ void read_embark(piece_info_t *list, int piece_type)
 
     piece_info_t *ship;
     piece_info_t *obj;
-    int count;
 
     for (ship = list; ship != NULL; ship = ship->piece_link.next) {
-	count = ship->count; /* get # of pieces we need */
+	int count = ship->count; /* get # of pieces we need */
 	if (count < 0) inconsistent ();
 	ship->count = 0; /* nothing on board yet */
 	for (obj = map[ship->loc].objp; obj && count;
@@ -749,10 +760,9 @@ print it using a zoomed display.
 void
 replay_movie(void)
 {
-    void print_movie_cell();
+    void print_movie_cell(char *, int, int, int, int);
 
     FILE *f; /* file to save game in */
-    int row_inc, col_inc;
     int r, c;
     int round;
 
@@ -765,6 +775,7 @@ replay_movie(void)
     round = 0;
     clear_screen ();
     for (;;) {
+	int row_inc, col_inc;
 	if (fread ((char *)mapbuf, 1, sizeof (mapbuf), f) != sizeof (mapbuf))
 	    break;
 	round += 1;
@@ -803,12 +814,11 @@ void stat_display(char *mbuf, int round)
     count_t i;
     int counts[2*NUM_OBJECTS+2];
     int user_cost, comp_cost;
-    char *p;
 	
     (void) memset ((char *)counts, '\0', sizeof (counts));
 	
     for (i = 0; i < MAP_SIZE; i++) {
-	p = strchr (pieces, mbuf[i]);
+	char *p = strchr (pieces, mbuf[i]);
 	if (p) counts[p-pieces] += 1;
     }
     user_cost = 0;
