@@ -24,9 +24,9 @@ extern int get_piece_name(void);
 void
 user_move(void)
 {
-    void piece_move();
+    void piece_move(piece_info_t *);
 
-    int i, j, sec, sec_start;
+    int i, j, sec_start;
     piece_info_t *obj, *next_obj;
     int prod;
 
@@ -74,7 +74,7 @@ user_move(void)
 
     /* loop through sectors, moving every piece in the sector */
     for (i = sec_start; i < sec_start + NUM_SECTORS; i++) {
-	sec = i % NUM_SECTORS;
+	int sec = i % NUM_SECTORS;
 	sector_change (); /* allow screen to be redrawn */
 
 	for (j = 0; j < NUM_OBJECTS; j++) /* loop through obj lists */
@@ -104,16 +104,16 @@ the piece has not moved after this, we ask the user what to do.
 void
 piece_move(piece_info_t *obj)
 {
-    void move_random(), move_fill(), move_land(), move_explore();
-    void move_path(), move_dir(), move_armyload(), ask_user();
-    void move_armyattack(), move_ttload(), move_repair();
-    void move_transport();
+    void move_random(piece_info_t *), move_fill(piece_info_t *);
+    void move_land(piece_info_t *), move_explore(piece_info_t *);
+    void move_path(piece_info_t *), move_dir(piece_info_t *); 
+    void move_armyload(piece_info_t *), ask_user(piece_info_t *);
+    void move_armyattack(piece_info_t *), move_ttload(piece_info_t *);
+    void move_repair(piece_info_t *), move_transport(piece_info_t *);
 
     bool changed_loc;
     int speed, max_hits;
-    int saved_moves;
     bool need_input;
-    loc_t saved_loc;
     city_info_t *cityp;
 
     /* set func for piece if on city */
@@ -128,8 +128,8 @@ piece_move(piece_info_t *obj)
     need_input = false; /* don't require user input yet */
 
     while (obj->moved < obj_moves (obj)) {
-	saved_moves = obj->moved; /* save moves made */
-	saved_loc = obj->loc; /* remember starting location */
+	int saved_moves = obj->moved; /* save moves made */
+	loc_t saved_loc = obj->loc; /* remember starting location */
 
 	if (awake (obj) || need_input){ /* need user input? */
 	    ask_user (obj);
@@ -208,12 +208,11 @@ void move_random(piece_info_t *obj)
 {
     loc_t loc_list[8];
     int i, nloc;
-    loc_t loc;
 
     nloc = 0;
 
     for (i = 0; i < 8; i++) {
-	loc = obj->loc + dir_offset[i];
+	loc_t loc = obj->loc + dir_offset[i];
 	if (good_loc (obj, loc)) {
 	    loc_list[nloc] = loc; /* remember this location */
 	    nloc++; /* count locations we can move to */
@@ -406,13 +405,12 @@ move_land(piece_info_t *obj)
 {
     long best_dist;
     loc_t best_loc;
-    long new_dist;
     piece_info_t *p;
 
     best_dist = find_nearest_city (obj->loc, USER, &best_loc);
 
     for (p = user_obj[CARRIER]; p != NULL; p = p->piece_link.next) {
-	new_dist = dist (obj->loc, p->loc);
+	long new_dist = dist (obj->loc, p->loc);
 	if (new_dist < best_dist) {
 	    best_dist = new_dist;
 	    best_loc = p->loc;
@@ -504,16 +502,19 @@ Ask the user to move her piece.
 
 void ask_user(piece_info_t *obj)
 {
-    void user_skip(), user_fill(), user_dir(), user_set_dir();
-    void user_wake(), user_set_city_func(), user_cancel_auto();
-    void user_redraw(), user_random(), user_land(), user_sentry();
-    void user_help(), reset_func(), user_explore();
-    void user_build(), user_transport();
-    void user_armyattack(), user_repair();
-
-    char c;
+    void user_skip(piece_info_t *), user_fill(piece_info_t *);
+    void user_dir(piece_info_t *, int), user_set_dir(piece_info_t *);
+    void user_wake(piece_info_t *), user_set_city_func(piece_info_t *);
+    void user_cancel_auto(void), user_redraw(void);
+    void user_random(piece_info_t *), user_land(piece_info_t *);
+    void user_sentry(piece_info_t *), user_help(void);
+    void reset_func(piece_info_t *), user_explore(piece_info_t *);
+    void user_build(piece_info_t *), user_transport(piece_info_t *);
+    void user_armyattack(piece_info_t *), user_repair(piece_info_t *);
 
     for (;;) {
+	char c;
+
 	display_loc_u (obj->loc); /* display piece to move */
 	describe_obj (obj); /* describe object to be moved */
 	display_score (); /* show current score */
@@ -738,9 +739,13 @@ Set a city's function.
 void
 user_set_city_func(piece_info_t *obj)
 {
-    void e_city_fill(), e_city_explore(), e_city_stasis();
-    void e_city_wake(), e_city_random(), e_city_repair();
-    void e_city_attack();
+    void e_city_fill(city_info_t *, int);
+    void e_city_explore(city_info_t *, int);
+    void e_city_stasis(city_info_t *, int);
+    void e_city_wake(city_info_t *, int);
+    void e_city_random(city_info_t *, int);
+    void e_city_repair(city_info_t *, int);
+    void e_city_attack(city_info_t *, int);
 	
     int type;
     char e;
@@ -814,7 +819,9 @@ This routine handles attacking objects.
 void
 user_dir(piece_info_t *obj, int dir)
 {
-    void user_dir_army(), user_dir_fighter(), user_dir_ship();
+    void user_dir_army(piece_info_t *, loc_t);
+    void user_dir_fighter(piece_info_t *, loc_t);
+    void user_dir_ship(piece_info_t *, loc_t);
 
     loc_t loc;
 
@@ -1037,7 +1044,6 @@ bool
 awake(piece_info_t *obj)
 {
     int i;
-    char c;
     long t;
 
     if (obj->type == ARMY && vmap_at_sea (user_map, obj->loc)) {
@@ -1054,7 +1060,7 @@ awake(piece_info_t *obj)
 	return (true);
     }
     for (i = 0; i < 8; i++) { /* for each surrounding cell */
-	c = user_map[obj->loc+dir_offset[i]].contents;
+	char c = user_map[obj->loc+dir_offset[i]].contents;
 
 	if (islower (c) || c == MAP_CITY || c == 'X') {
 	    if (obj->func < 0) obj->func = NOFUNC; /* awaken */
