@@ -80,7 +80,9 @@ static bool in_cargo[LIST_SIZE]; /* true if object in a cargo list */
 void
 check(void)
 {
-    void check_cargo(), check_obj(), check_obj_cargo();
+    void check_cargo(piece_info_t *, int);
+    void check_obj(piece_info_t **, int);
+    void check_obj_cargo(piece_info_t **);
 	
     long i, j;
     piece_info_t *p;
@@ -212,10 +214,10 @@ void
 check_cargo(piece_info_t *list, int cargo_type)
 {
     piece_info_t *p, *q;
-    long j, count;
+    long j;
 	
     for (p = list; p != NULL; p = p->piece_link.next) {
-	count = 0;
+	long count = 0;
 	for (q = p->cargo; q != NULL; q = q->cargo_link.next) {
 	    count += 1; /* count items in list */
 	    ASSERT (q->type == cargo_type);
